@@ -1,6 +1,6 @@
 ﻿# "This is a template and example of configuration file for Sim::OPT.
 
-$mypath = "/home/luca/tep" ;# path of the directory in which you are going to work
+$mypath = "/home/luca/tp" ;# path of the directory in which you are going to work
 ##@sweeps = ( [ [ 1 ] ] );
 #@sweeps = ( [ [ 1, 2, 3, 4 ] ] );
 #@sweeps = ( [ [ 1, 2, 3], [2, 3, 4] , [ 3, 4, 5], [4, 5, 6 ] ] );
@@ -17,7 +17,7 @@ $mypath = "/home/luca/tep" ;# path of the directory in which you are going to wo
 ##@varinumbers = ( { 1 => 2 } );
 #@varinumbers = ( { 1 => 3, 2 => 3, 3 => 3, 4 => 3 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 #@varinumbers = ( { 1 => 3, 2 => 3, 3 => 3, 4 => 3, 5 => 3, 6 => 3 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
-@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 8, 7 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
+@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 4, 7 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 #@varinumbers = ( { 1 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS'
 # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' } ); # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' }, { 1 => '3', 2 => '3', 3 => '3' } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE NUMBER OF ITERATIONS FOR EACH VARIABLES ARE SPECIFIED.
@@ -26,12 +26,12 @@ $mypath = "/home/luca/tep" ;# path of the directory in which you are going to wo
 #@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2 } );
 #@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 2 } );
 ##@mediumiters = ( { 1 => 1  } );
-@mediumiters = ( { 1 => 1, 2 => 1, 3 => 1, 4 => 1, 5 => 1, 6 => 4, 7 => 1 } ); # OR: @mediumiters = ( { 1 => 2, 2 => 2, 3 => 2 } );
+@mediumiters = ( { 1 => 1, 2 => 1, 3 => 1, 4 => 1, 5 => 1, 6 => 2, 7 => 1 } ); # OR: @mediumiters = ( { 1 => 2, 2 => 2, 3 => 2 } );
 #@mediumiters = ( { 1 => 1 } ); # OR: @mediumiters = ( { 1 => 2, 2 => 2, 3 => 2 } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
 # IF LEFT UNSPECIFIED IT DEFAULTS TO THE MIDDLE ITERATION FOR EACH VARIABLE.  # IF LEFT UNSPECIFIED IT DEFAULTS TO THE CENTRAL VALUE FOR EACH GIVEN RANGE. 
 
-$file = "t";  # the root model directory.
+$file = "tp";  # the root model directory.
 
 %dowhat = ( # This variables tells to the program what to do.
 morph => "y", # create cases for simulation?
@@ -687,7 +687,7 @@ $vals{1}{2}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASF
 [ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
 [ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
 "/ep/newbox21.idf", # FILE TO BE MODIFIED.
-[ [ 199, 200, 201, 202, 214, 215, 229, 230, 231, 232, 246, 247, 259, 262, 275, 276 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
+[ [ 199, 200, 201, 202, 214, 215, 246, 247, 259, 262, 275, 276 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
 [ 2 ], [ 0, -1.5 ], [  ], "linear", ",", 5  ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type("linear"_or_"rotation2d"_or_"wordchange"_), "separator"(e.g. "," - optional), precision(number_of_decimals) ]; # IF "wordchange" IS SPECIFIED, THE LIST OF WORDS TO BE PUT IN PLACE OF THE CHOSEN ITEM(S) MUST BE PLACED IN THE SAME SQUARE BRAKETS THAT FOR  OTHER CHANGE_TYPES ARE USED FOR THE max & min VALUES. 
 ]
 ]
@@ -766,7 +766,7 @@ $vals{1}{6}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASF
 289, 290, 291, 292, 304, 305, 306, 307, 319, 320, 321, 322, 334, 335, 336, 337, 349, 350, 351, 352, 364, 365, 366, 367,
 379, 380, 381, 382, 394, 395, 396, 397, 409, 410, 411, 412, 424, 425, 426, 427, 439, 440, 441, 442, 454, 455, 456, 457,
 490, 491, 492, 493, 506, 507, 508, 509, 522, 523, 524, 525, 538, 539, 540, 541, 554, 555, 556, 557, 570, 571, 572, 573, 586, 587, 588, 589 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
-[ 1, 2 ], [ -135, 180 ], [  ], "rotation2d", ",", 5, [ 0, 0 ] ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type("linear"_or_"rotation2d"_or_"wordchange"_), "separator"(e.g. "," - optional), precision(number_of_decimals) ]; # IF "wordchange" IS SPECIFIED, THE LIST OF WORDS TO BE PUT IN PLACE OF THE CHOSEN ITEM(S) MUST BE PLACED IN THE SAME SQUARE BRAKETS THAT FOR  OTHER CHANGE_TYPES ARE USED FOR THE max & min VALUES. 
+[ 1, 2 ], [ -90, 180 ], [  ], "rotation2d", ",", 5, [ 0, 0 ] ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type("linear"_or_"rotation2d"_or_"wordchange"_), "separator"(e.g. "," - optional), precision(number_of_decimals) ]; # IF "wordchange" IS SPECIFIED, THE LIST OF WORDS TO BE PUT IN PLACE OF THE CHOSEN ITEM(S) MUST BE PLACED IN THE SAME SQUARE BRAKETS THAT FOR  OTHER CHANGE_TYPES ARE USED FOR THE max & min VALUES. 
 ]
 ]
 ]
@@ -783,7 +783,7 @@ $vals{1}{7}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASF
 [ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
 [ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
 "/ep/newbox21.idf", # FILE TO BE MODIFIED.
-[ [ 936 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
+[ [ 741 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
 [ 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13 ], [ 0, 0.6 ], [  ], "linear", ",", 5 ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type("linear"_or_"rotation2d"_or_"wordchange"_), "separator"(e.g. "," - optional), precision(number_of_decimals) ]; # IF "wordchange" IS SPECIFIED, THE LIST OF WORDS TO BE PUT IN PLACE OF THE CHOSEN ITEM(S) MUST BE PLACED IN THE SAME SQUARE BRAKETS THAT FOR  OTHER CHANGE_TYPES ARE USED FOR THE max & min VALUES. 
 ]
 ]
