@@ -23,7 +23,7 @@ use Sim::OPT::Sim;
 use Sim::OPT::Descend;
 use Sim::OPT::Takechance;
 use Sim::OPT::Modish;
-use Parallel::ForkManager;
+#use Parallel::ForkManager;
 use Data::Dumper;
 #$Data::Dumper::Indent = 0;
 #$Data::Dumper::Useqq  = 1;
@@ -1071,11 +1071,11 @@ sub report # This function retrieves the results of interest from the texts file
               }
               
               $line =~ s/  / / ;
-		  	  $line =~ s/  / / ;
-		  	  $line =~ s/  / / ;
-		  	  $line =~ s/  / / ;
-		  	  $line =~ s/  / / ;
-  			  $line =~ s/ /,/ ;
+		  	      $line =~ s/  / / ;
+		  	      $line =~ s/  / / ;
+		  	      $line =~ s/  / / ;
+		  	      $line =~ s/  / / ;
+  			      $line =~ s/ /,/ ;
               chomp( $line ); chomp( $line ); 
               #$line = $line . " ";
               
@@ -1124,6 +1124,12 @@ sub report # This function retrieves the results of interest from the texts file
                     {  
                       if ( not ( $afterlin =~ /-/ ) )
                       {
+                         $afterlin =~ s/  / / ;
+                         $afterlin =~ s/  / / ;
+                         $afterlin =~ s/  / / ;
+                         $afterlin =~ s/  / / ;
+                         $afterlin =~ s/  / / ;
+                         $afterlin =~ s/ /,/ ;
                         push ( @bringer, $afterlin );
                       }
                       else
@@ -1208,9 +1214,20 @@ sub report # This function retrieves the results of interest from the texts file
   
   #foreach ( sort ( @{ $convey[ $countcase ][ $counblock ] } ) )
   #{
+    $_ =~ s/  / / ;
+    $_ =~ s/  / / ;
+    $_ =~ s/  / / ;
+    $_ =~ s/  / / ;
+    $_ =~ s/  / / ;
+    $_ =~ s/ /,/ ;
+
     print REPFILE "$_\n"; 
   #}
   close REPFILE;
+
+  my $repstore = $repfile . ".csv";
+  `cp -f $repfile $repstore`;
+  print REPORT "cp -f $repfile $repstore\n";
     
   say $tee "HEREIS \@repcases " . dump(@repcases); say $tee "\@repstruct " . dump(@repstruct); 
   
